import type { GraphQueryResultMetaFromBackend } from 'ts-common';
import { log } from '../../logger';
import { QUERY_CACHE_DURATION, redis } from '../../variables';

export async function cacheCheck(cacheKey: string): Promise<GraphQueryResultMetaFromBackend | undefined> {
  log.debug('Checking cache for query, with cache ttl', QUERY_CACHE_DURATION, 'seconds');
  const cached = await redis.client.get(cacheKey);
  if (cached) {
    log.info('Cache hit for query');
    const buf = Buffer.from(cached, 'base64');
    const inflated = Bun.gunzipSync(new Uint8Array(buf));
    const dec = new TextDecoder();
    const cachedMessage = JSON.parse(dec.decode(inflated)) as GraphQueryResultMetaFromBackend;
    return cachedMessage;
  }
}
